# Changelog

## [0.3.0](https://github.com/tkk2112/cmakepresets/compare/v0.2.6...v0.3.0) (2025-03-19)


### ⚠ BREAKING CHANGES

* missing s on project script

### Bug Fixes

* missing s on project script ([94da3e4](https://github.com/tkk2112/cmakepresets/commit/94da3e4104850337d9cdaa0c07b60f1ebe5c595f))

## [0.2.6](https://github.com/tkk2112/cmakepresets/compare/v0.2.5...v0.2.6) (2025-03-18)


### Bug Fixes

* project version file was wrongly registered in config ([491c2c9](https://github.com/tkk2112/cmakepresets/commit/491c2c92df80996b0210ca7824dad60582f87e14))

## [0.2.5](https://github.com/tkk2112/cmakepresets/compare/v0.2.1...v0.2.5) (2025-03-18)


### Features

* add release-please to module ([fe61f58](https://github.com/tkk2112/cmakepresets/commit/fe61f58484a77cbb69bc639623b42be213033299))


### Bug Fixes

* prefix version and add to README.md ([47fcbc6](https://github.com/tkk2112/cmakepresets/commit/47fcbc6da10e8f23384c6b50c377197c3d04bf78))
